;/**
; *******************************************************************************
; * @file    startup_TMPM411_unitA.s
; * @brief   CMSIS Cortex-M4 Core Device Startup File for the
; *          TOSHIBA 'TMPM411_unitA' Device Series
; * @version V2.0.2.2 (Tentative)
; * @date    2014/07/23
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
; * 
; * (C)Copyright TOSHIBA CORPORATION 2014 All rights reserved
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     MemManage_Handler         ; MPU Fault Handler
                DCD     BusFault_Handler          ; Bus Fault Handler
                DCD     UsageFault_Handler        ; Usage Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     DebugMon_Handler          ; Debug Monitor Handler
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     INTPWRDETF_IRQHandler     ; 0:	INT_PWRDET pin Interrupt (Falling edge)
                DCD     INTPWRDETR_IRQHandler     ; 1:	INT_PWRDET pin Interrupt (Rising edge)
                DCD     INT0_IRQHandler           ; 2:	Interrupt pin 0
                DCD     INT1_IRQHandler           ; 3:	Interrupt pin 1
                DCD     INT2_IRQHandler           ; 4:	Interrupt pin 2
                DCD     INT3_IRQHandler           ; 5:	Interrupt pin 3
                DCD     INT4_IRQHandler           ; 6:	Interrupt pin 4
                DCD     INTCPUIF0_IRQHandler      ; 7:	CPU Interface 0 Interrupt
                DCD     INTEVENT_IRQHandler       ; 8:	INT_EVENT pin Interrupt (Rising edge)
                DCD     INTDISPRQ_IRQHandler      ; 9:	INT_DISPRQ pin Interrupt (Rising edge)
                DCD     INTRX0_IRQHandler         ; 10:	Serial0 reception interrupt
                DCD     INTTX0_IRQHandler         ; 11:	Serial0 transmission interrupt
                DCD     INTRX1_IRQHandler         ; 12:	Serial1 reception interrupt
                DCD     INTTX1_IRQHandler         ; 13:	Serial1 transmission interrupt
                DCD     INTUART0_IRQHandler       ; 14:	Full UART0 transmission and reception interrupt
                DCD     INTI2C0_IRQHandler        ; 15:	I2C0 interrupt
                DCD     INTSSP0_IRQHandler        ; 16:	SSP0 interrupt
                DCD     INTSSP1_IRQHandler        ; 17:	SSP1 interrupt
                DCD     INTSSP2_IRQHandler        ; 18:	SSP2 interrupt
                DCD     INTADAHP_IRQHandler       ; 19:	High Priority AD conversion interrupt (unitA)
                DCD     INTADAM0_IRQHandler       ; 20:	AD conversion monitor 0 interrupt (unitA)
                DCD     INTADAM1_IRQHandler       ; 21:	AD conversion monitor 1 interrupt (unitA)
                DCD     INTADA_IRQHandler         ; 22:	Nornal AD conversion interrupt (unitA)
                DCD     INTTB0_IRQHandler         ; 23:	16-bit TMRB0 compare match detection interrupt
                DCD     INTCAP00_IRQHandler       ; 24:	16-bit TMRB0 input capture 0 detection interrupt
                DCD     INTCAP01_IRQHandler       ; 25:	16-bit TMRB0 input capture 1 detection interrupt
                DCD     INTTB1_IRQHandler         ; 26:	16-bit TMRB1 compare match detection interrupt
                DCD     INTCAP10_IRQHandler       ; 27:	16-bit TMRB1 input capture 0 detection interrupt
                DCD     INTCAP11_IRQHandler       ; 28:	16-bit TMRB1 input capture 1 detection interrupt
                DCD     INTTB2_IRQHandler         ; 29:	16-bit TMRB2 compare match detection interrupt
                DCD     INTCAP20_IRQHandler       ; 30:	16-bit TMRB2 input capture 0 detection interrupt
                DCD     INTCAP21_IRQHandler       ; 31:	16-bit TMRB2 input capture 1 detection interrupt
                DCD     INTT16A0_IRQHandler       ; 32:	16-bit TMR16A0 match detection
                DCD     INTT16A1_IRQHandler       ; 33:	16-bit TMR16A1 match detection
                DCD     INTSDALM_IRQHandler       ; 34:	Alarm interrupt
                DCD     INTRTC_IRQHandler         ; 35:	Real time counter interupt
                DCD     INTDMAATC0_IRQHandler     ; 36:	DMAC 0 transmission completion interrupt (unitA)
                DCD     INTDMAATC1_IRQHandler     ; 37:	DMAC 1 transmission completion interrupt (unitA)
                DCD     INTDMAATC2_IRQHandler     ; 38:	DMAC 2 transmission completion interrupt (unitA)
                DCD     INTDMAATC3_IRQHandler     ; 39:	DMAC 3 transmission completion interrupt (unitA)
                DCD     INTDMAATC4_IRQHandler     ; 40:	DMAC 4 transmission completion interrupt (unitA)
                DCD     INTDMAATC5_IRQHandler     ; 41:	DMAC 5 transmission completion interrupt (unitA)
                DCD     INTDMAATC6_IRQHandler     ; 42:	DMAC 6 transmission completion interrupt (unitA)
                DCD     INTDMAATC7_IRQHandler     ; 43:	DMAC 7 transmission completion interrupt (unitA)
                DCD     INTDMAATC8_IRQHandler     ; 44:	DMAC 8 transmission completion interrupt (unitA)
                DCD     INTDMAATC9_IRQHandler     ; 45:	DMAC 9 transmission completion interrupt (unitA)
                DCD     INTDMAATC10_IRQHandler    ; 46:	DMAC 10 transmission completion interrupt (unitA)
                DCD     INTDMAATC11_IRQHandler    ; 47:	DMAC 11 transmission completion interrupt (unitA)
                DCD     INTDMAATC12_IRQHandler    ; 48:	DMAC 12 transmission completion interrupt (unitA)
                DCD     INTDMAATC13_IRQHandler    ; 49:	DMAC 13 transmission completion interrupt (unitA)
                DCD     INTDMAATC14_IRQHandler    ; 50:	DMAC 14 transmission completion interrupt (unitA)
                DCD     INTDMAATC15_IRQHandler    ; 51:	DMAC 15 transmission completion interrupt (unitA)
                DCD     INTDMAATC16_IRQHandler    ; 52:	DMAC 16 transmission completion interrupt (unitA)
                DCD     INTDMAAERR_IRQHandler     ; 53:	DMAC transmissioni error interrupt (unitA)
                DCD     INTFLRDY_IRQHandler       ; 54:	Flash Ready interrupt



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INTPWRDETF_IRQHandler     [WEAK]
                EXPORT  INTPWRDETR_IRQHandler     [WEAK]
                EXPORT  INT0_IRQHandler           [WEAK]
                EXPORT  INT1_IRQHandler           [WEAK]
                EXPORT  INT2_IRQHandler           [WEAK]
                EXPORT  INT3_IRQHandler           [WEAK]
                EXPORT  INT4_IRQHandler           [WEAK]
                EXPORT  INTCPUIF0_IRQHandler      [WEAK]
                EXPORT  INTEVENT_IRQHandler       [WEAK]
                EXPORT  INTDISPRQ_IRQHandler      [WEAK]
                EXPORT  INTRX0_IRQHandler         [WEAK]
                EXPORT  INTTX0_IRQHandler         [WEAK]
                EXPORT  INTRX1_IRQHandler         [WEAK]
                EXPORT  INTTX1_IRQHandler         [WEAK]
                EXPORT  INTUART0_IRQHandler       [WEAK]
                EXPORT  INTI2C0_IRQHandler        [WEAK]
                EXPORT  INTSSP0_IRQHandler        [WEAK]
                EXPORT  INTSSP1_IRQHandler        [WEAK]
                EXPORT  INTSSP2_IRQHandler        [WEAK]
                EXPORT  INTADAHP_IRQHandler       [WEAK]
                EXPORT  INTADAM0_IRQHandler       [WEAK]
                EXPORT  INTADAM1_IRQHandler       [WEAK]
                EXPORT  INTADA_IRQHandler         [WEAK]
                EXPORT  INTTB0_IRQHandler         [WEAK]
                EXPORT  INTCAP00_IRQHandler       [WEAK]
                EXPORT  INTCAP01_IRQHandler       [WEAK]
                EXPORT  INTTB1_IRQHandler         [WEAK]
                EXPORT  INTCAP10_IRQHandler       [WEAK]
                EXPORT  INTCAP11_IRQHandler       [WEAK]
                EXPORT  INTTB2_IRQHandler         [WEAK]
                EXPORT  INTCAP20_IRQHandler       [WEAK]
                EXPORT  INTCAP21_IRQHandler       [WEAK]
                EXPORT  INTT16A0_IRQHandler       [WEAK]
                EXPORT  INTT16A1_IRQHandler       [WEAK]
                EXPORT  INTSDALM_IRQHandler       [WEAK]
                EXPORT  INTRTC_IRQHandler         [WEAK]
                EXPORT  INTDMAATC0_IRQHandler     [WEAK]
                EXPORT  INTDMAATC1_IRQHandler     [WEAK]
                EXPORT  INTDMAATC2_IRQHandler     [WEAK]
                EXPORT  INTDMAATC3_IRQHandler     [WEAK]
                EXPORT  INTDMAATC4_IRQHandler     [WEAK]
                EXPORT  INTDMAATC5_IRQHandler     [WEAK]
                EXPORT  INTDMAATC6_IRQHandler     [WEAK]
                EXPORT  INTDMAATC7_IRQHandler     [WEAK]
                EXPORT  INTDMAATC8_IRQHandler     [WEAK]
                EXPORT  INTDMAATC9_IRQHandler     [WEAK]
                EXPORT  INTDMAATC10_IRQHandler    [WEAK]
                EXPORT  INTDMAATC11_IRQHandler    [WEAK]
                EXPORT  INTDMAATC12_IRQHandler    [WEAK]
                EXPORT  INTDMAATC13_IRQHandler    [WEAK]
                EXPORT  INTDMAATC14_IRQHandler    [WEAK]
                EXPORT  INTDMAATC15_IRQHandler    [WEAK]
                EXPORT  INTDMAATC16_IRQHandler    [WEAK]
                EXPORT  INTDMAAERR_IRQHandler     [WEAK]
                EXPORT  INTFLRDY_IRQHandler       [WEAK]

INTPWRDETF_IRQHandler
INTPWRDETR_IRQHandler
INT0_IRQHandler
INT1_IRQHandler
INT2_IRQHandler
INT3_IRQHandler
INT4_IRQHandler
INTCPUIF0_IRQHandler
INTEVENT_IRQHandler
INTDISPRQ_IRQHandler
INTRX0_IRQHandler
INTTX0_IRQHandler
INTRX1_IRQHandler
INTTX1_IRQHandler
INTUART0_IRQHandler
INTI2C0_IRQHandler
INTSSP0_IRQHandler
INTSSP1_IRQHandler
INTSSP2_IRQHandler
INTADAHP_IRQHandler
INTADAM0_IRQHandler
INTADAM1_IRQHandler
INTADA_IRQHandler
INTTB0_IRQHandler
INTCAP00_IRQHandler
INTCAP01_IRQHandler
INTTB1_IRQHandler
INTCAP10_IRQHandler
INTCAP11_IRQHandler
INTTB2_IRQHandler
INTCAP20_IRQHandler
INTCAP21_IRQHandler
INTT16A0_IRQHandler
INTT16A1_IRQHandler
INTSDALM_IRQHandler
INTRTC_IRQHandler
INTDMAATC0_IRQHandler
INTDMAATC1_IRQHandler
INTDMAATC2_IRQHandler
INTDMAATC3_IRQHandler
INTDMAATC4_IRQHandler
INTDMAATC5_IRQHandler
INTDMAATC6_IRQHandler
INTDMAATC7_IRQHandler
INTDMAATC8_IRQHandler
INTDMAATC9_IRQHandler
INTDMAATC10_IRQHandler
INTDMAATC11_IRQHandler
INTDMAATC12_IRQHandler
INTDMAATC13_IRQHandler
INTDMAATC14_IRQHandler
INTDMAATC15_IRQHandler
INTDMAATC16_IRQHandler
INTDMAAERR_IRQHandler
INTFLRDY_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

