;/**
; *******************************************************************************
; * @file    startup_TMPM411_unitB.s
; * @brief   CMSIS Cortex-M4 Core Device Startup File for the
; *          TOSHIBA 'TMPM411_unitB' Device Series
; * @version V2.0.2.2 (Tentative)
; * @date    2014/07/23
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
; * 
; * (C)Copyright TOSHIBA CORPORATION 2014 All rights reserved
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     MemManage_Handler         ; MPU Fault Handler
                DCD     BusFault_Handler          ; Bus Fault Handler
                DCD     UsageFault_Handler        ; Usage Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     DebugMon_Handler          ; Debug Monitor Handler
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     INTPWRDETF_IRQHandler     ; 0:	INT_PWRDET pin Interrupt (Falling edge)
                DCD     INTPWRDETR_IRQHandler     ; 1:	INT_PWRDET pin Interrupt (Rising edge)
                DCD     INT5_IRQHandler           ; 2:	Interrupt pin 5
                DCD     INT6_IRQHandler           ; 3:	Interrupt pin 6
                DCD     INT7_IRQHandler           ; 4:	Interrupt pin 7
                DCD     INT8_IRQHandler           ; 5:	Interrupt pin 8
                DCD     INTCPUIF1_IRQHandler      ; 6:	CPU Interface 1 Interrupt
                DCD     INTRX2_IRQHandler         ; 7:	Serial2 reception interrupt
                DCD     INTTX2_IRQHandler         ; 8:	Serial2 transmission interrupt
                DCD     INTRX3_IRQHandler         ; 9:	Serial3 reception interrupt
                DCD     INTTX3_IRQHandler         ; 10:	Serial3 transmission interrupt
                DCD     INTRX4_IRQHandler         ; 11:	Serial4 reception interrupt
                DCD     INTTX4_IRQHandler         ; 12:	Serial4 transmission interrupt
                DCD     INTRX5_IRQHandler         ; 13:	Serial5 reception interrupt
                DCD     INTTX5_IRQHandler         ; 14:	Serial5 transmission interrupt
                DCD     INTUART1_IRQHandler       ; 15:	Full UART1 transmission and reception interrupt
                DCD     INTSSP3_IRQHandler        ; 16:	SSP3 interrupt
                DCD     INTADBHP_IRQHandler       ; 17:	High Priority AD conversion interrupt (unitB)
                DCD     INTADBM0_IRQHandler       ; 18:	AD conversion monitor 0 interrupt (unitB)
                DCD     INTADBM1_IRQHandler       ; 19:	AD conversion monitor 1 interrupt (unitB)
                DCD     INTADB_IRQHandler         ; 20:	Nornal AD conversion interrupt (unitB)
                DCD     INTAES_IRQHandler         ; 21:	AES completion interrupt
                DCD     INTSHA_IRQHandler         ; 22:	SHA completion interrupt
                DCD     INTMLA_IRQHandler         ; 23:	MLA completion interrupt
                DCD     INTESG_IRQHandler         ; 24:	ESG completion interrupt
                DCD     INTTB3_IRQHandler         ; 25:	16-bit TMRB3 compare match detection interrupt
                DCD     INTCAP30_IRQHandler       ; 26:	16-bit TMRB3 input capture 0 detection interrupt
                DCD     INTCAP31_IRQHandler       ; 27:	16-bit TMRB3 input capture 1 detection interrupt
                DCD     INTTB4_IRQHandler         ; 28:	16-bit TMRB4 compare match detection interrupt
                DCD     INTCAP40_IRQHandler       ; 29:	16-bit TMRB4 input capture 0 detection interrupt
                DCD     INTCAP41_IRQHandler       ; 30:	16-bit TMRB4 input capture 1 detection interrupt
                DCD     INTT16A2_IRQHandler       ; 31:	16-bit TMR16A2 match detection
                DCD     INTT16A3_IRQHandler       ; 32:	16-bit TMR16A3 match detection
                DCD     INTDMABTC0_IRQHandler     ; 33:	DMAC0 transmission completion interrupt (unitB)
                DCD     INTDMABTC1_IRQHandler     ; 34:	DMAC1 transmission completion interrupt (unitB)
                DCD     INTDMABTC2_IRQHandler     ; 35:	DMAC2 transmission completion interrupt (unitB)
                DCD     INTDMABTC3_IRQHandler     ; 36:	DMAC3 transmission completion interrupt (unitB)
                DCD     INTDMABTC4_IRQHandler     ; 37:	DMAC4 transmission completion interrupt (unitB)
                DCD     INTDMABTC5_IRQHandler     ; 38:	DMAC5 transmission completion interrupt (unitB)
                DCD     INTDMABTC6_IRQHandler     ; 39:	DMAC6 transmission completion interrupt (unitB)
                DCD     INTDMABTC7_IRQHandler     ; 40:	DMAC7 transmission completion interrupt (unitB)
                DCD     INTDMABTC8_IRQHandler     ; 41:	DMAC8 transmission completion interrupt (unitB)
                DCD     INTDMABTC9_IRQHandler     ; 42:	DMAC9 transmission completion interrupt (unitB)
                DCD     INTDMABTC10_IRQHandler    ; 43:	DMAC10 transmission completion interrupt (unitB)
                DCD     INTDMABTC11_IRQHandler    ; 44:	DMAC11 transmission completion interrupt (unitB)
                DCD     INTDMABTC12_IRQHandler    ; 45:	DMAC12 transmission completion interrupt (unitB)
                DCD     INTDMABTC13_IRQHandler    ; 46:	DMAC13 transmission completion interrupt (unitB)
                DCD     INTDMABTC14_IRQHandler    ; 47:	DMAC14 transmission completion interrupt (unitB)
                DCD     INTDMABTC15_IRQHandler    ; 48:	DMAC15 transmission completion interrupt (unitB)
                DCD     INTDMABTC16_IRQHandler    ; 49:	DMAC16 transmission completion interrupt (unitB)
                DCD     INTDMABTC17_IRQHandler    ; 50:	DMAC17 transmission completion interrupt (unitB)
                DCD     INTDMABERR_IRQHandler     ; 51:	DMAC transmissioni error interrupt (unitB)
                DCD     INTFLRDY_IRQHandler       ; 52:	Flash Ready interrupt



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INTPWRDETF_IRQHandler     [WEAK]
                EXPORT  INTPWRDETR_IRQHandler     [WEAK]
                EXPORT  INT5_IRQHandler           [WEAK]
                EXPORT  INT6_IRQHandler           [WEAK]
                EXPORT  INT7_IRQHandler           [WEAK]
                EXPORT  INT8_IRQHandler           [WEAK]
                EXPORT  INTCPUIF1_IRQHandler      [WEAK]
                EXPORT  INTRX2_IRQHandler         [WEAK]
                EXPORT  INTTX2_IRQHandler         [WEAK]
                EXPORT  INTRX3_IRQHandler         [WEAK]
                EXPORT  INTTX3_IRQHandler         [WEAK]
                EXPORT  INTRX4_IRQHandler         [WEAK]
                EXPORT  INTTX4_IRQHandler         [WEAK]
                EXPORT  INTRX5_IRQHandler         [WEAK]
                EXPORT  INTTX5_IRQHandler         [WEAK]
                EXPORT  INTUART1_IRQHandler       [WEAK]
                EXPORT  INTSSP3_IRQHandler        [WEAK]
                EXPORT  INTADBHP_IRQHandler       [WEAK]
                EXPORT  INTADBM0_IRQHandler       [WEAK]
                EXPORT  INTADBM1_IRQHandler       [WEAK]
                EXPORT  INTADB_IRQHandler         [WEAK]
                EXPORT  INTAES_IRQHandler         [WEAK]
                EXPORT  INTSHA_IRQHandler         [WEAK]
                EXPORT  INTMLA_IRQHandler         [WEAK]
                EXPORT  INTESG_IRQHandler         [WEAK]
                EXPORT  INTTB3_IRQHandler         [WEAK]
                EXPORT  INTCAP30_IRQHandler       [WEAK]
                EXPORT  INTCAP31_IRQHandler       [WEAK]
                EXPORT  INTTB4_IRQHandler         [WEAK]
                EXPORT  INTCAP40_IRQHandler       [WEAK]
                EXPORT  INTCAP41_IRQHandler       [WEAK]
                EXPORT  INTT16A2_IRQHandler       [WEAK]
                EXPORT  INTT16A3_IRQHandler       [WEAK]
                EXPORT  INTDMABTC0_IRQHandler     [WEAK]
                EXPORT  INTDMABTC1_IRQHandler     [WEAK]
                EXPORT  INTDMABTC2_IRQHandler     [WEAK]
                EXPORT  INTDMABTC3_IRQHandler     [WEAK]
                EXPORT  INTDMABTC4_IRQHandler     [WEAK]
                EXPORT  INTDMABTC5_IRQHandler     [WEAK]
                EXPORT  INTDMABTC6_IRQHandler     [WEAK]
                EXPORT  INTDMABTC7_IRQHandler     [WEAK]
                EXPORT  INTDMABTC8_IRQHandler     [WEAK]
                EXPORT  INTDMABTC9_IRQHandler     [WEAK]
                EXPORT  INTDMABTC10_IRQHandler    [WEAK]
                EXPORT  INTDMABTC11_IRQHandler    [WEAK]
                EXPORT  INTDMABTC12_IRQHandler    [WEAK]
                EXPORT  INTDMABTC13_IRQHandler    [WEAK]
                EXPORT  INTDMABTC14_IRQHandler    [WEAK]
                EXPORT  INTDMABTC15_IRQHandler    [WEAK]
                EXPORT  INTDMABTC16_IRQHandler    [WEAK]
                EXPORT  INTDMABTC17_IRQHandler    [WEAK]
                EXPORT  INTDMABERR_IRQHandler     [WEAK]
                EXPORT  INTFLRDY_IRQHandler       [WEAK]

INTPWRDETF_IRQHandler
INTPWRDETR_IRQHandler
INT5_IRQHandler
INT6_IRQHandler
INT7_IRQHandler
INT8_IRQHandler
INTCPUIF1_IRQHandler
INTRX2_IRQHandler
INTTX2_IRQHandler
INTRX3_IRQHandler
INTTX3_IRQHandler
INTRX4_IRQHandler
INTTX4_IRQHandler
INTRX5_IRQHandler
INTTX5_IRQHandler
INTUART1_IRQHandler
INTSSP3_IRQHandler
INTADBHP_IRQHandler
INTADBM0_IRQHandler
INTADBM1_IRQHandler
INTADB_IRQHandler
INTAES_IRQHandler
INTSHA_IRQHandler
INTMLA_IRQHandler
INTESG_IRQHandler
INTTB3_IRQHandler
INTCAP30_IRQHandler
INTCAP31_IRQHandler
INTTB4_IRQHandler
INTCAP40_IRQHandler
INTCAP41_IRQHandler
INTT16A2_IRQHandler
INTT16A3_IRQHandler
INTDMABTC0_IRQHandler
INTDMABTC1_IRQHandler
INTDMABTC2_IRQHandler
INTDMABTC3_IRQHandler
INTDMABTC4_IRQHandler
INTDMABTC5_IRQHandler
INTDMABTC6_IRQHandler
INTDMABTC7_IRQHandler
INTDMABTC8_IRQHandler
INTDMABTC9_IRQHandler
INTDMABTC10_IRQHandler
INTDMABTC11_IRQHandler
INTDMABTC12_IRQHandler
INTDMABTC13_IRQHandler
INTDMABTC14_IRQHandler
INTDMABTC15_IRQHandler
INTDMABTC16_IRQHandler
INTDMABTC17_IRQHandler
INTDMABERR_IRQHandler
INTFLRDY_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

