;/**
; *******************************************************************************
; * @file    startup_TMPM440.s
; * @brief   CMSIS Cortex-M4 Core Device Startup File for the
; *          TOSHIBA 'TMPM440' Device Series
; * @version V2.0.2.1 (Tentative)
; * @date    2012/07/12
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * THE SOURCE CODE AND ITS RELATED DOCUMENTATION IS PROVIDED "AS IS". TOSHIBA
; * CORPORATION MAKES NO OTHER WARRANTY OF ANY KIND, WHETHER EXPRESS, IMPLIED OR,
; * STATUTORY AND DISCLAIMS ANY AND ALL IMPLIED WARRANTIES OF MERCHANTABILITY,
; * SATISFACTORY QUALITY, NON INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
; * 
; * THE SOURCE CODE AND DOCUMENTATION MAY INCLUDE ERRORS. TOSHIBA CORPORATION
; * RESERVES THE RIGHT TO INCORPORATE MODIFICATIONS TO THE SOURCE CODE IN LATER
; * REVISIONS OF IT, AND TO MAKE IMPROVEMENTS OR CHANGES IN THE DOCUMENTATION OR
; * THE PRODUCTS OR TECHNOLOGIES DESCRIBED THEREIN AT ANY TIME.
; * 
; * TOSHIBA CORPORATION SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT OR
; * CONSEQUENTIAL DAMAGE OR LIABILITY ARISING FROM YOUR USE OF THE SOURCE CODE OR
; * ANY DOCUMENTATION, INCLUDING BUT NOT LIMITED TO, LOST REVENUES, DATA OR
; * PROFITS, DAMAGES OF ANY SPECIAL, INCIDENTAL OR CONSEQUENTIAL NATURE, PUNITIVE
; * DAMAGES, LOSS OF PROPERTY OR LOSS OF PROFITS ARISING OUT OF OR IN CONNECTION
; * WITH THIS AGREEMENT, OR BEING UNUSABLE, EVEN IF ADVISED OF THE POSSIBILITY OR
; * PROBABILITY OF SUCH DAMAGES AND WHETHER A CLAIM FOR SUCH DAMAGE IS BASED UPON
; * WARRANTY, CONTRACT, TORT, NEGLIGENCE OR OTHERWISE.
; * 
; * (C)Copyright TOSHIBA CORPORATION 2012 All rights reserved
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     MemManage_Handler         ; MPU Fault Handler
                DCD     BusFault_Handler          ; Bus Fault Handler
                DCD     UsageFault_Handler        ; Usage Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     DebugMon_Handler          ; Debug Monitor Handler
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     INT0_IRQHandler           ; 0:	Interrupt pin 0
                DCD     INT1_IRQHandler           ; 1:	Interrupt pin 1
                DCD     INT2_IRQHandler           ; 2:	Interrupt pin 2
                DCD     INT3_IRQHandler           ; 3:	Interrupt pin 3
                DCD     INT4_IRQHandler           ; 4:	Interrupt pin 4
                DCD     INT5_IRQHandler           ; 5:	Interrupt pin 5
                DCD     INT6_IRQHandler           ; 6:	Interrupt pin 6
                DCD     INT7_IRQHandler           ; 7:	Interrupt pin 7
                DCD     INT8_IRQHandler           ; 8:	Interrupt pin 8
                DCD     INT9_IRQHandler           ; 9:	Interrupt pin 9
                DCD     INTA_IRQHandler           ; 10:	Interrupt pin A
                DCD     INTB_IRQHandler           ; 11:	Interrupt pin B
                DCD     INTC_IRQHandler           ; 12:	Interrupt pin C
                DCD     INTD_IRQHandler           ; 13:	Interrupt pin D
                DCD     INTE_IRQHandler           ; 14:	Interrupt pin E
                DCD     INTF_IRQHandler           ; 15:	Interrupt pin F
                DCD     INT10_IRQHandler          ; 16:	Interrupt pin 10
                DCD     INT11_IRQHandler          ; 17:	Interrupt pin 11
                DCD     INT12_IRQHandler          ; 18:	Interrupt pin 12
                DCD     INT13_IRQHandler          ; 19:	Interrupt pin 13
                DCD     INT14_IRQHandler          ; 20:	Interrupt pin 14
                DCD     INT15_IRQHandler          ; 21:	Interrupt pin 15
                DCD     INTKWUPA_IRQHandler       ; 22:	Key on wake up interrupt (unitA)
                DCD     INTKWUPB_IRQHandler       ; 23:	Key on wake up interrupt (unitB)
                DCD     INTKSCAN_IRQHandler       ; 24:	Key matrix scan interupt
                DCD     INTRTC_IRQHandler         ; 25:	Real time counter interupt
                DCD     INT16_IRQHandler          ; 26:	Interrupt pin 16
                DCD     INT17_IRQHandler          ; 27:	Interrupt pin 17
                DCD     INTPSCSTOP_IRQHandler     ; 28:	PSC end interrupt
                DCD     INTPSCBRK_IRQHandler      ; 29:	PSC break interrupt
                DCD     INTPSCSTEP_IRQHandler     ; 30:	PSC step interrupt
                DCD     INTPSCII_IRQHandler       ; 31:	PSC unjustified instruction interrupt
                DCD     INTPSCIA_IRQHandler       ; 32:	PSC unjustified address interrupt
                DCD     INTE0RX_IRQHandler        ; 33:	ESIO 0 reception interrupt
                DCD     INTE0TX_IRQHandler        ; 34:	ESIO 0 transmission interrupt
                DCD     INTE0ERR_IRQHandler       ; 35:	ESIO 0 error interrupt
                DCD     INTE1RX_IRQHandler        ; 36:	ESIO 1 reception interrupt
                DCD     INTE1TX_IRQHandler        ; 37:	ESIO 1 transmission interrupt
                DCD     INTE1ERR_IRQHandler       ; 38:	ESIO 1 error interrupt
                DCD     INTE2RX_IRQHandler        ; 39:	ESIO 2 reception interrupt
                DCD     INTE2TX_IRQHandler        ; 40:	ESIO 2 transmission interrupt
                DCD     INTE2ERR_IRQHandler       ; 41:	ESIO 2 error interrupt
                DCD     INTRX0_IRQHandler         ; 42:	Serial0 reception interrupt
                DCD     INTTX0_IRQHandler         ; 43:	Serial0 transmission interrupt
                DCD     INTRX1_IRQHandler         ; 44:	Serial1 reception interrupt
                DCD     INTTX1_IRQHandler         ; 45:	Serial1 transmission interrupt
                DCD     INTRX2_IRQHandler         ; 46:	Serial2 reception interrupt
                DCD     INTTX2_IRQHandler         ; 47:	Serial2 transmission interrupt
                DCD     INTRX3_IRQHandler         ; 48:	Serial3 reception interrupt
                DCD     INTTX3_IRQHandler         ; 49:	Serial3 transmission interrupt
                DCD     INTRX4_IRQHandler         ; 50:	Serial4 reception interrupt
                DCD     INTTX4_IRQHandler         ; 51:	Serial4 transmission interrupt
                DCD     INTRX5_IRQHandler         ; 52:	Serial5 reception interrupt
                DCD     INTTX5_IRQHandler         ; 53:	Serial5 transmission interrupt
                DCD     INTUART0_IRQHandler       ; 54:	Full UART0 transmission and reception interrupt
                DCD     INTUART1_IRQHandler       ; 55:	Full UART1 transmission and reception interrupt
                DCD     INTI2C_IRQHandler         ; 56:	I2C interrupt
                DCD     INTADA_IRQHandler         ; 57:	AD conversion interrupt (unitA)
                DCD     INTADB_IRQHandler         ; 58:	AD conversion interrupt (unitB)
                DCD     INTADC_IRQHandler         ; 59:	AD conversion interrupt (unitC)
                DCD     INTTB00_IRQHandler        ; 60:	16-bit TMRB00 compare match detection interrupt
                DCD     INTTB01_IRQHandler        ; 61:	16-bit TMRB01 compare match detection interrupt
                DCD     INTTB02_IRQHandler        ; 62:	16-bit TMRB02 compare match detection interrupt
                DCD     INTTB03_IRQHandler        ; 63:	16-bit TMRB03 compare match detection interrupt
                DCD     INTTB04_IRQHandler        ; 64:	16-bit TMRB04 compare match detection interrupt
                DCD     INTTB05_IRQHandler        ; 65:	16-bit TMRB05 compare match detection interrupt
                DCD     INTTB06_IRQHandler        ; 66:	16-bit TMRB06 compare match detection interrupt
                DCD     INTTB07_IRQHandler        ; 67:	16-bit TMRB07 compare match detection interrupt
                DCD     INTTB08_IRQHandler        ; 68:	16-bit TMRB08 compare match detection interrupt
                DCD     INTTB09_IRQHandler        ; 69:	16-bit TMRB09 compare match detection interrupt
                DCD     INTTB10_IRQHandler        ; 70:	16-bit TMRB10 compare match detection interrupt
                DCD     INTTB11_IRQHandler        ; 71:	16-bit TMRB11 compare match detection interrupt
                DCD     INTTB12_IRQHandler        ; 72:	16-bit TMRB12 compare match detection interrupt
                DCD     INTTB13_IRQHandler        ; 73:	16-bit TMRB13 compare match detection interrupt
                DCD     INTTB14_IRQHandler        ; 74:	16-bit TMRB14 compare match detection interrupt
                DCD     INTTB15_IRQHandler        ; 75:	16-bit TMRB15 compare match detection interrupt
                DCD     INTTB16_IRQHandler        ; 76:	16-bit TMRB16 compare match detection interrupt
                DCD     INTTB17_IRQHandler        ; 77:	16-bit TMRB17 compare match detection interrupt
                DCD     INTTB18_IRQHandler        ; 78:	16-bit TMRB18 compare match detection interrupt
                DCD     INTTB19_IRQHandler        ; 79:	16-bit TMRB19 compare match detection interrupt
                DCD     INTTCCMP0_IRQHandler      ; 80:	32-bit TMRC0 compare match detection interrupt
                DCD     INTTCCMP1_IRQHandler      ; 81:	32-bit TMRC1 compare match detection interrupt
                DCD     INTTCCMP2_IRQHandler      ; 82:	32-bit TMRC2 compare match detection interrupt
                DCD     INTTCCMP3_IRQHandler      ; 83:	32-bit TMRC3 compare match detection interrupt
                DCD     INTTCCMP4_IRQHandler      ; 84:	32-bit TMRC4 compare match detection interrupt
                DCD     INTTCCMP5_IRQHandler      ; 85:	32-bit TMRC5 compare match detection interrupt
                DCD     INTTCCMP6_IRQHandler      ; 86:	32-bit TMRC6 compare match detection interrupt
                DCD     INTTCCMP7_IRQHandler      ; 87:	32-bit TMRC7 compare match detection interrupt
                DCD     INTTCCAP0_IRQHandler      ; 88:	32-bit TMRC0 input capture detection interrupt
                DCD     INTTCCAP1_IRQHandler      ; 89:	32-bit TMRC1 input capture detection interrupt
                DCD     INTTCCAP2_IRQHandler      ; 90:	32-bit TMRC2 input capture detection interrupt
                DCD     INTTCCAP3_IRQHandler      ; 91:	32-bit TMRC3 input capture detection interrupt
                DCD     INTPHC00_IRQHandler       ; 92:	16-bit PHC0 compare match detection interrupt 0
                DCD     INTPHC01_IRQHandler       ; 93:	16-bit PHC0 compare match detection interrupt 1
                DCD     INTPHC0EVRY_IRQHandler    ; 94:	16-bit PHC0 every count interrupt
                DCD     INTPHC10_IRQHandler       ; 95:	16-bit PHC1 compare match detection interrupt 0
                DCD     INTPHC11_IRQHandler       ; 96:	16-bit PHC1 compare match detection interrupt 1
                DCD     INTPHC1EVRY_IRQHandler    ; 97:	16-bit PHC1 every count interrupt
                DCD     INTEPHC_IRQHandler        ; 98:	Two-phase pulse input counter interrupt
                DCD     INTPHCPOVF_IRQHandler     ; 99:	PHCP overflow interrupt
                DCD     INTPHCPPHE_IRQHandler     ; 100:	PHCP phase error interrupt
                DCD     INTPHCPCY0_IRQHandler     ; 101:	PHCP cycle interrupt 0
                DCD     INTPHCPCY1_IRQHandler     ; 102:	PHCP cycle interrupt 1
                DCD     INTPHCPCY2_IRQHandler     ; 103:	PHCP cycle interrupt 2
                DCD     INTPHCPCY3_IRQHandler     ; 104:	PHCP cycle interrupt 3
                DCD     INTTD0CMP0_IRQHandler     ; 105:	TMRD0 compare match detection interrupt 0
                DCD     INTTD0CMP1_IRQHandler     ; 106:	TMRD0 compare match detection interrupt 1
                DCD     INTTD0CMP2_IRQHandler     ; 107:	TMRD0 compare match detection interrupt 2
                DCD     INTTD0CMP3_IRQHandler     ; 108:	TMRD0 compare match detection interrupt 3
                DCD     INTTD0CMP4_IRQHandler     ; 109:	TMRD0 compare match detection interrupt 4
                DCD     INTTD1CMP0_IRQHandler     ; 110:	TMRD1 compare match detection interrupt 0
                DCD     INTTD1CMP1_IRQHandler     ; 111:	TMRD1 compare match detection interrupt 1
                DCD     INTTD1CMP2_IRQHandler     ; 112:	TMRD1 compare match detection interrupt 2
                DCD     INTTD1CMP3_IRQHandler     ; 113:	TMRD1 compare match detection interrupt 3
                DCD     INTTD1CMP4_IRQHandler     ; 114:	TMRD1 compare match detection interrupt 4
                DCD     INTADAHP_IRQHandler       ; 115:	High Priority AD conversion interrupt (channel.A)
                DCD     INTADBHP_IRQHandler       ; 116:	High Priority AD conversion interrupt (channel.B)
                DCD     INTADCHP_IRQHandler       ; 117:	High Priority AD conversion interrupt (channel.C)
                DCD     INTTB07CAP0_IRQHandler    ; 118:	16-bit TMRB07 input capture 0 detection interrupt
                DCD     INTTB07CAP1_IRQHandler    ; 119:	16-bit TMRB07 input capture 1 detection interrupt
                DCD     INTTB08CAP0_IRQHandler    ; 120:	16-bit TMRB08 input capture 0 detection interrupt
                DCD     INTTB08CAP1_IRQHandler    ; 121:	16-bit TMRB08 input capture 1 detection interrupt
                DCD     INTTB09CAP0_IRQHandler    ; 122:	16-bit TMRB09 input capture 0 detection interrupt
                DCD     INTTB09CAP1_IRQHandler    ; 123:	16-bit TMRB09 input capture 1 detection interrupt
                DCD     INTTB10CAP0_IRQHandler    ; 124:	16-bit TMRB10 input capture 0 detection interrupt
                DCD     INTTB10CAP1_IRQHandler    ; 125:	16-bit TMRB10 input capture 1 detection interrupt
                DCD     INTTB11CAP0_IRQHandler    ; 126:	16-bit TMRB11 input capture 0 detection interrupt
                DCD     INTTB11CAP1_IRQHandler    ; 127:	16-bit TMRB11 input capture 1 detection interrupt
                DCD     INTTB12CAP0_IRQHandler    ; 128:	16-bit TMRB12 input capture 0 detection interrupt
                DCD     INTTB12CAP1_IRQHandler    ; 129:	16-bit TMRB12 input capture 1 detection interrupt
                DCD     INTTB13CAP0_IRQHandler    ; 130:	16-bit TMRB13 input capture 0 detection interrupt
                DCD     INTTB13CAP1_IRQHandler    ; 131:	16-bit TMRB13 input capture 1 detection interrupt
                DCD     INTTB14CAP0_IRQHandler    ; 132:	16-bit TMRB14 input capture 0 detection interrupt
                DCD     INTTB14CAP1_IRQHandler    ; 133:	16-bit TMRB14 input capture 1 detection interrupt
                DCD     INTTB15CAP0_IRQHandler    ; 134:	16-bit TMRB15 input capture 0 detection interrupt
                DCD     INTTB15CAP1_IRQHandler    ; 135:	16-bit TMRB15 input capture 1 detection interrupt
                DCD     INTTB16CAP0_IRQHandler    ; 136:	16-bit TMRB16 input capture 0 detection interrupt
                DCD     INTTB16CAP1_IRQHandler    ; 137:	16-bit TMRB16 input capture 1 detection interrupt
                DCD     INTTB17CAP0_IRQHandler    ; 138:	16-bit TMRB17 input capture 0 detection interrupt
                DCD     INTTB17CAP1_IRQHandler    ; 139:	16-bit TMRB17 input capture 1 detection interrupt
                DCD     INTTB18CAP0_IRQHandler    ; 140:	16-bit TMRB18 input capture 0 detection interrupt
                DCD     INTTB18CAP1_IRQHandler    ; 141:	16-bit TMRB18 input capture 1 detection interrupt
                DCD     INTTB19CAP0_IRQHandler    ; 142:	16-bit TMRB19 input capture 0 detection interrupt
                DCD     INTTB19CAP1_IRQHandler    ; 143:	16-bit TMRB19 input capture 1 detection interrupt
                DCD     INTADAM0_IRQHandler       ; 144:	SAR ADC monitor 0 interrupt (unitA)
                DCD     INTADAM1_IRQHandler       ; 145:	SAR ADC monitor 1 interrupt (unitA)
                DCD     INTADBM0_IRQHandler       ; 146:	SAR ADC monitor 0 interrupt (unitB)
                DCD     INTADBM1_IRQHandler       ; 147:	SAR ADC monitor 1 interrupt (unitB)
                DCD     INTADCM0_IRQHandler       ; 148:	SAR ADC monitor 0 interrupt (unitC)
                DCD     INTADCM1_IRQHandler       ; 149:	SAR ADC monitor 1 interrupt (unitC)
                DCD     INTDMACATC_IRQHandler     ; 150:	DMA terminal count status interrupt (unitA)
                DCD     INTDMACAERR_IRQHandler    ; 151:	DMA error status interrupt (unitA)
                DCD     INTDMACBTC_IRQHandler     ; 152:	DMA terminal count status interrupt (unitB)
                DCD     INTDMACBERR_IRQHandler    ; 153:	DMA error status interrupt (unitB)
                DCD     INTDMACCTC_IRQHandler     ; 154:	DMA terminal count status interrupt (unitC)
                DCD     INTDMACCERR_IRQHandler    ; 155:	DMA error status interrupt (unitC)
                DCD     INTTCTBT_IRQHandler       ; 156:	32-bit TMRC overflow interrupt



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INT0_IRQHandler           [WEAK]
                EXPORT  INT1_IRQHandler           [WEAK]
                EXPORT  INT2_IRQHandler           [WEAK]
                EXPORT  INT3_IRQHandler           [WEAK]
                EXPORT  INT4_IRQHandler           [WEAK]
                EXPORT  INT5_IRQHandler           [WEAK]
                EXPORT  INT6_IRQHandler           [WEAK]
                EXPORT  INT7_IRQHandler           [WEAK]
                EXPORT  INT8_IRQHandler           [WEAK]
                EXPORT  INT9_IRQHandler           [WEAK]
                EXPORT  INTA_IRQHandler           [WEAK]
                EXPORT  INTB_IRQHandler           [WEAK]
                EXPORT  INTC_IRQHandler           [WEAK]
                EXPORT  INTD_IRQHandler           [WEAK]
                EXPORT  INTE_IRQHandler           [WEAK]
                EXPORT  INTF_IRQHandler           [WEAK]
                EXPORT  INT10_IRQHandler          [WEAK]
                EXPORT  INT11_IRQHandler          [WEAK]
                EXPORT  INT12_IRQHandler          [WEAK]
                EXPORT  INT13_IRQHandler          [WEAK]
                EXPORT  INT14_IRQHandler          [WEAK]
                EXPORT  INT15_IRQHandler          [WEAK]
                EXPORT  INTKWUPA_IRQHandler       [WEAK]
                EXPORT  INTKWUPB_IRQHandler       [WEAK]
                EXPORT  INTKSCAN_IRQHandler       [WEAK]
                EXPORT  INTRTC_IRQHandler         [WEAK]
                EXPORT  INT16_IRQHandler          [WEAK]
                EXPORT  INT17_IRQHandler          [WEAK]
                EXPORT  INTPSCSTOP_IRQHandler     [WEAK]
                EXPORT  INTPSCBRK_IRQHandler      [WEAK]
                EXPORT  INTPSCSTEP_IRQHandler     [WEAK]
                EXPORT  INTPSCII_IRQHandler       [WEAK]
                EXPORT  INTPSCIA_IRQHandler       [WEAK]
                EXPORT  INTE0RX_IRQHandler        [WEAK]
                EXPORT  INTE0TX_IRQHandler        [WEAK]
                EXPORT  INTE0ERR_IRQHandler       [WEAK]
                EXPORT  INTE1RX_IRQHandler        [WEAK]
                EXPORT  INTE1TX_IRQHandler        [WEAK]
                EXPORT  INTE1ERR_IRQHandler       [WEAK]
                EXPORT  INTE2RX_IRQHandler        [WEAK]
                EXPORT  INTE2TX_IRQHandler        [WEAK]
                EXPORT  INTE2ERR_IRQHandler       [WEAK]
                EXPORT  INTRX0_IRQHandler         [WEAK]
                EXPORT  INTTX0_IRQHandler         [WEAK]
                EXPORT  INTRX1_IRQHandler         [WEAK]
                EXPORT  INTTX1_IRQHandler         [WEAK]
                EXPORT  INTRX2_IRQHandler         [WEAK]
                EXPORT  INTTX2_IRQHandler         [WEAK]
                EXPORT  INTRX3_IRQHandler         [WEAK]
                EXPORT  INTTX3_IRQHandler         [WEAK]
                EXPORT  INTRX4_IRQHandler         [WEAK]
                EXPORT  INTTX4_IRQHandler         [WEAK]
                EXPORT  INTRX5_IRQHandler         [WEAK]
                EXPORT  INTTX5_IRQHandler         [WEAK]
                EXPORT  INTUART0_IRQHandler       [WEAK]
                EXPORT  INTUART1_IRQHandler       [WEAK]
                EXPORT  INTI2C_IRQHandler         [WEAK]
                EXPORT  INTADA_IRQHandler         [WEAK]
                EXPORT  INTADB_IRQHandler         [WEAK]
                EXPORT  INTADC_IRQHandler         [WEAK]
                EXPORT  INTTB00_IRQHandler        [WEAK]
                EXPORT  INTTB01_IRQHandler        [WEAK]
                EXPORT  INTTB02_IRQHandler        [WEAK]
                EXPORT  INTTB03_IRQHandler        [WEAK]
                EXPORT  INTTB04_IRQHandler        [WEAK]
                EXPORT  INTTB05_IRQHandler        [WEAK]
                EXPORT  INTTB06_IRQHandler        [WEAK]
                EXPORT  INTTB07_IRQHandler        [WEAK]
                EXPORT  INTTB08_IRQHandler        [WEAK]
                EXPORT  INTTB09_IRQHandler        [WEAK]
                EXPORT  INTTB10_IRQHandler        [WEAK]
                EXPORT  INTTB11_IRQHandler        [WEAK]
                EXPORT  INTTB12_IRQHandler        [WEAK]
                EXPORT  INTTB13_IRQHandler        [WEAK]
                EXPORT  INTTB14_IRQHandler        [WEAK]
                EXPORT  INTTB15_IRQHandler        [WEAK]
                EXPORT  INTTB16_IRQHandler        [WEAK]
                EXPORT  INTTB17_IRQHandler        [WEAK]
                EXPORT  INTTB18_IRQHandler        [WEAK]
                EXPORT  INTTB19_IRQHandler        [WEAK]
                EXPORT  INTTCCMP0_IRQHandler      [WEAK]
                EXPORT  INTTCCMP1_IRQHandler      [WEAK]
                EXPORT  INTTCCMP2_IRQHandler      [WEAK]
                EXPORT  INTTCCMP3_IRQHandler      [WEAK]
                EXPORT  INTTCCMP4_IRQHandler      [WEAK]
                EXPORT  INTTCCMP5_IRQHandler      [WEAK]
                EXPORT  INTTCCMP6_IRQHandler      [WEAK]
                EXPORT  INTTCCMP7_IRQHandler      [WEAK]
                EXPORT  INTTCCAP0_IRQHandler      [WEAK]
                EXPORT  INTTCCAP1_IRQHandler      [WEAK]
                EXPORT  INTTCCAP2_IRQHandler      [WEAK]
                EXPORT  INTTCCAP3_IRQHandler      [WEAK]
                EXPORT  INTPHC00_IRQHandler       [WEAK]
                EXPORT  INTPHC01_IRQHandler       [WEAK]
                EXPORT  INTPHC0EVRY_IRQHandler    [WEAK]
                EXPORT  INTPHC10_IRQHandler       [WEAK]
                EXPORT  INTPHC11_IRQHandler       [WEAK]
                EXPORT  INTPHC1EVRY_IRQHandler    [WEAK]
                EXPORT  INTEPHC_IRQHandler        [WEAK]
                EXPORT  INTPHCPOVF_IRQHandler     [WEAK]
                EXPORT  INTPHCPPHE_IRQHandler     [WEAK]
                EXPORT  INTPHCPCY0_IRQHandler     [WEAK]
                EXPORT  INTPHCPCY1_IRQHandler     [WEAK]
                EXPORT  INTPHCPCY2_IRQHandler     [WEAK]
                EXPORT  INTPHCPCY3_IRQHandler     [WEAK]
                EXPORT  INTTD0CMP0_IRQHandler     [WEAK]
                EXPORT  INTTD0CMP1_IRQHandler     [WEAK]
                EXPORT  INTTD0CMP2_IRQHandler     [WEAK]
                EXPORT  INTTD0CMP3_IRQHandler     [WEAK]
                EXPORT  INTTD0CMP4_IRQHandler     [WEAK]
                EXPORT  INTTD1CMP0_IRQHandler     [WEAK]
                EXPORT  INTTD1CMP1_IRQHandler     [WEAK]
                EXPORT  INTTD1CMP2_IRQHandler     [WEAK]
                EXPORT  INTTD1CMP3_IRQHandler     [WEAK]
                EXPORT  INTTD1CMP4_IRQHandler     [WEAK]
                EXPORT  INTADAHP_IRQHandler       [WEAK]
                EXPORT  INTADBHP_IRQHandler       [WEAK]
                EXPORT  INTADCHP_IRQHandler       [WEAK]
                EXPORT  INTTB07CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB07CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB08CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB08CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB09CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB09CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB10CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB10CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB11CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB11CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB12CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB12CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB13CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB13CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB14CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB14CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB15CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB15CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB16CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB16CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB17CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB17CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB18CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB18CAP1_IRQHandler    [WEAK]
                EXPORT  INTTB19CAP0_IRQHandler    [WEAK]
                EXPORT  INTTB19CAP1_IRQHandler    [WEAK]
                EXPORT  INTADAM0_IRQHandler       [WEAK]
                EXPORT  INTADAM1_IRQHandler       [WEAK]
                EXPORT  INTADBM0_IRQHandler       [WEAK]
                EXPORT  INTADBM1_IRQHandler       [WEAK]
                EXPORT  INTADCM0_IRQHandler       [WEAK]
                EXPORT  INTADCM1_IRQHandler       [WEAK]
                EXPORT  INTDMACATC_IRQHandler     [WEAK]
                EXPORT  INTDMACAERR_IRQHandler    [WEAK]
                EXPORT  INTDMACBTC_IRQHandler     [WEAK]
                EXPORT  INTDMACBERR_IRQHandler    [WEAK]
                EXPORT  INTDMACCTC_IRQHandler     [WEAK]
                EXPORT  INTDMACCERR_IRQHandler    [WEAK]
                EXPORT  INTTCTBT_IRQHandler       [WEAK]

INT0_IRQHandler
INT1_IRQHandler
INT2_IRQHandler
INT3_IRQHandler
INT4_IRQHandler
INT5_IRQHandler
INT6_IRQHandler
INT7_IRQHandler
INT8_IRQHandler
INT9_IRQHandler
INTA_IRQHandler
INTB_IRQHandler
INTC_IRQHandler
INTD_IRQHandler
INTE_IRQHandler
INTF_IRQHandler
INT10_IRQHandler
INT11_IRQHandler
INT12_IRQHandler
INT13_IRQHandler
INT14_IRQHandler
INT15_IRQHandler
INTKWUPA_IRQHandler
INTKWUPB_IRQHandler
INTKSCAN_IRQHandler
INTRTC_IRQHandler
INT16_IRQHandler
INT17_IRQHandler
INTPSCSTOP_IRQHandler
INTPSCBRK_IRQHandler
INTPSCSTEP_IRQHandler
INTPSCII_IRQHandler
INTPSCIA_IRQHandler
INTE0RX_IRQHandler
INTE0TX_IRQHandler
INTE0ERR_IRQHandler
INTE1RX_IRQHandler
INTE1TX_IRQHandler
INTE1ERR_IRQHandler
INTE2RX_IRQHandler
INTE2TX_IRQHandler
INTE2ERR_IRQHandler
INTRX0_IRQHandler
INTTX0_IRQHandler
INTRX1_IRQHandler
INTTX1_IRQHandler
INTRX2_IRQHandler
INTTX2_IRQHandler
INTRX3_IRQHandler
INTTX3_IRQHandler
INTRX4_IRQHandler
INTTX4_IRQHandler
INTRX5_IRQHandler
INTTX5_IRQHandler
INTUART0_IRQHandler
INTUART1_IRQHandler
INTI2C_IRQHandler
INTADA_IRQHandler
INTADB_IRQHandler
INTADC_IRQHandler
INTTB00_IRQHandler
INTTB01_IRQHandler
INTTB02_IRQHandler
INTTB03_IRQHandler
INTTB04_IRQHandler
INTTB05_IRQHandler
INTTB06_IRQHandler
INTTB07_IRQHandler
INTTB08_IRQHandler
INTTB09_IRQHandler
INTTB10_IRQHandler
INTTB11_IRQHandler
INTTB12_IRQHandler
INTTB13_IRQHandler
INTTB14_IRQHandler
INTTB15_IRQHandler
INTTB16_IRQHandler
INTTB17_IRQHandler
INTTB18_IRQHandler
INTTB19_IRQHandler
INTTCCMP0_IRQHandler
INTTCCMP1_IRQHandler
INTTCCMP2_IRQHandler
INTTCCMP3_IRQHandler
INTTCCMP4_IRQHandler
INTTCCMP5_IRQHandler
INTTCCMP6_IRQHandler
INTTCCMP7_IRQHandler
INTTCCAP0_IRQHandler
INTTCCAP1_IRQHandler
INTTCCAP2_IRQHandler
INTTCCAP3_IRQHandler
INTPHC00_IRQHandler
INTPHC01_IRQHandler
INTPHC0EVRY_IRQHandler
INTPHC10_IRQHandler
INTPHC11_IRQHandler
INTPHC1EVRY_IRQHandler
INTEPHC_IRQHandler
INTPHCPOVF_IRQHandler
INTPHCPPHE_IRQHandler
INTPHCPCY0_IRQHandler
INTPHCPCY1_IRQHandler
INTPHCPCY2_IRQHandler
INTPHCPCY3_IRQHandler
INTTD0CMP0_IRQHandler
INTTD0CMP1_IRQHandler
INTTD0CMP2_IRQHandler
INTTD0CMP3_IRQHandler
INTTD0CMP4_IRQHandler
INTTD1CMP0_IRQHandler
INTTD1CMP1_IRQHandler
INTTD1CMP2_IRQHandler
INTTD1CMP3_IRQHandler
INTTD1CMP4_IRQHandler
INTADAHP_IRQHandler
INTADBHP_IRQHandler
INTADCHP_IRQHandler
INTTB07CAP0_IRQHandler
INTTB07CAP1_IRQHandler
INTTB08CAP0_IRQHandler
INTTB08CAP1_IRQHandler
INTTB09CAP0_IRQHandler
INTTB09CAP1_IRQHandler
INTTB10CAP0_IRQHandler
INTTB10CAP1_IRQHandler
INTTB11CAP0_IRQHandler
INTTB11CAP1_IRQHandler
INTTB12CAP0_IRQHandler
INTTB12CAP1_IRQHandler
INTTB13CAP0_IRQHandler
INTTB13CAP1_IRQHandler
INTTB14CAP0_IRQHandler
INTTB14CAP1_IRQHandler
INTTB15CAP0_IRQHandler
INTTB15CAP1_IRQHandler
INTTB16CAP0_IRQHandler
INTTB16CAP1_IRQHandler
INTTB17CAP0_IRQHandler
INTTB17CAP1_IRQHandler
INTTB18CAP0_IRQHandler
INTTB18CAP1_IRQHandler
INTTB19CAP0_IRQHandler
INTTB19CAP1_IRQHandler
INTADAM0_IRQHandler
INTADAM1_IRQHandler
INTADBM0_IRQHandler
INTADBM1_IRQHandler
INTADCM0_IRQHandler
INTADCM1_IRQHandler
INTDMACATC_IRQHandler
INTDMACAERR_IRQHandler
INTDMACBTC_IRQHandler
INTDMACBERR_IRQHandler
INTDMACCTC_IRQHandler
INTDMACCERR_IRQHandler
INTTCTBT_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

