;/**
; *******************************************************************************
; * @file    startup_TMPM462.s
; * @brief   CMSIS Cortex-M4 Core Device Startup File for the
; *          TOSHIBA 'TMPM462' Device Series
; * @version V2.0.2.2 (Tentative)
; * @date    2013/08/12
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * THE SOURCE CODE AND ITS RELATED DOCUMENTATION IS PROVIDED "AS IS". TOSHIBA
; * CORPORATION MAKES NO OTHER WARRANTY OF ANY KIND, WHETHER EXPRESS, IMPLIED OR,
; * STATUTORY AND DISCLAIMS ANY AND ALL IMPLIED WARRANTIES OF MERCHANTABILITY,
; * SATISFACTORY QUALITY, NON INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
; * 
; * THE SOURCE CODE AND DOCUMENTATION MAY INCLUDE ERRORS. TOSHIBA CORPORATION
; * RESERVES THE RIGHT TO INCORPORATE MODIFICATIONS TO THE SOURCE CODE IN LATER
; * REVISIONS OF IT, AND TO MAKE IMPROVEMENTS OR CHANGES IN THE DOCUMENTATION OR
; * THE PRODUCTS OR TECHNOLOGIES DESCRIBED THEREIN AT ANY TIME.
; * 
; * TOSHIBA CORPORATION SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT OR
; * CONSEQUENTIAL DAMAGE OR LIABILITY ARISING FROM YOUR USE OF THE SOURCE CODE OR
; * ANY DOCUMENTATION, INCLUDING BUT NOT LIMITED TO, LOST REVENUES, DATA OR
; * PROFITS, DAMAGES OF ANY SPECIAL, INCIDENTAL OR CONSEQUENTIAL NATURE, PUNITIVE
; * DAMAGES, LOSS OF PROPERTY OR LOSS OF PROFITS ARISING OUT OF OR IN CONNECTION
; * WITH THIS AGREEMENT, OR BEING UNUSABLE, EVEN IF ADVISED OF THE POSSIBILITY OR
; * PROBABILITY OF SUCH DAMAGES AND WHETHER A CLAIM FOR SUCH DAMAGE IS BASED UPON
; * WARRANTY, CONTRACT, TORT, NEGLIGENCE OR OTHERWISE.
; * 
; * (C)Copyright TOSHIBA CORPORATION 2013 All rights reserved
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     MemManage_Handler         ; MPU Fault Handler
                DCD     BusFault_Handler          ; Bus Fault Handler
                DCD     UsageFault_Handler        ; Usage Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     DebugMon_Handler          ; Debug Monitor Handler
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     INT0_IRQHandler           ; 0:	Interrupt pin 0
                DCD     INT1_IRQHandler           ; 1:	Interrupt pin 1
                DCD     INT2_IRQHandler           ; 2:	Interrupt pin 2
                DCD     INT3_IRQHandler           ; 3:	Interrupt pin 3
                DCD     INT4_IRQHandler           ; 4:	Interrupt pin 4
                DCD     INT5_IRQHandler           ; 5:	Interrupt pin 5
                DCD     INT6_IRQHandler           ; 6:	Interrupt pin 6
                DCD     INT7_IRQHandler           ; 7:	Interrupt pin 7
                DCD     INT8_IRQHandler           ; 8:	Interrupt pin 8
                DCD     INT9_IRQHandler           ; 9:	Interrupt pin 9
                DCD     INTA_IRQHandler           ; 10:	Interrupt pin A
                DCD     INTB_IRQHandler           ; 11:	Interrupt pin B
                DCD     INTC_IRQHandler           ; 12:	Interrupt pin C
                DCD     INTD_IRQHandler           ; 13:	Interrupt pin D
                DCD     INTE_IRQHandler           ; 14:	Interrupt pin E
                DCD     INTF_IRQHandler           ; 15:	Interrupt pin F
                DCD     INTRX0_IRQHandler         ; 16:	Serial0 reception interrupt
                DCD     INTTX0_IRQHandler         ; 17:	Serial0 transmission interrupt
                DCD     INTRX1_IRQHandler         ; 18:	Serial1 reception interrupt
                DCD     INTTX1_IRQHandler         ; 19:	Serial1 transmission interrupt
                DCD     INTRX2_IRQHandler         ; 20:	Serial2 reception interrupt
                DCD     INTTX2_IRQHandler         ; 21:	Serial2 transmission interrupt
                DCD     INTRX3_IRQHandler         ; 22:	Serial3 reception interrupt
                DCD     INTTX3_IRQHandler         ; 23:	Serial3 transmission interrupt
                DCD     INTRX4_IRQHandler         ; 24:	Serial4 reception interrupt
                DCD     INTTX4_IRQHandler         ; 25:	Serial4 transmission interrupt
                DCD     INTRX5_IRQHandler         ; 26:	Serial5 reception interrupt
                DCD     INTTX5_IRQHandler         ; 27:	Serial5 transmission interrupt
                DCD     INTUART0_IRQHandler       ; 28:	Full UART0 transmission and reception interrupt
                DCD     INTUART1_IRQHandler       ; 29:	Full UART1 transmission and reception interrupt
                DCD     INTI2C0_IRQHandler        ; 30:	I2C0 transmission and reception interrupt
                DCD     INTI2C1_IRQHandler        ; 31:	I2C1 transmission and reception interrupt
                DCD     INTI2C2_IRQHandler        ; 32:	I2C2 transmission and reception interrupt
                DCD     INTI2C3_IRQHandler        ; 33:	I2C3 transmission and reception interrupt
                DCD     INTI2C4_IRQHandler        ; 34:	I2C4 transmission and reception interrupt
                DCD     INTSSP0_IRQHandler        ; 35:	SSP(SPI) Serial interface 0 interrupt 
                DCD     INTSSP1_IRQHandler        ; 36:	SSP(SPI) Serial interface 1 interrupt 
                DCD     INTSSP2_IRQHandler        ; 37:	SSP(SPI) Serial interface 2 interrupt 
                DCD     INTCECRX_IRQHandler       ; 38:	CEC reception interrupt
                DCD     INTCECTX_IRQHandler       ; 39:	CEC transmission interrupt
                DCD     INTRMCRX0_IRQHandler      ; 40:	Remote control rececptio 0 interrupt
                DCD     INTADHP_IRQHandler        ; 41:	High Priority AD conversion interrupt
                DCD     INTADM0_IRQHandler        ; 42:	AD conversion monitor interrupt 0
                DCD     INTADM1_IRQHandler        ; 43:	AD conversion monitor interrupt 1
                DCD     INTAD_IRQHandler          ; 44:	AD conversion interrupt 
                DCD     INTRTC_IRQHandler         ; 45:	Real time clock interrupt
                DCD     INTMTEMG0_IRQHandler      ; 46:	MPT0 EMG interrupt
                DCD     INTMTPTB00_IRQHandler     ; 47:	MPT0 compare match0/overflow,IGBT cycle interrupt
                DCD     INTMTPTB01_IRQHandler     ; 48:	MPT0 compare match1/overflow,IGBT cycle interrupt
                DCD     INTMTCAP00_IRQHandler     ; 49:	MPT0 input capture0 interrupt
                DCD     INTMTCAP01_IRQHandler     ; 50:	MPT0 input capture1 interrupt
                DCD     INTMTEMG1_IRQHandler      ; 51:	MPT1 EMG interrupt
                DCD     INTMTPTB10_IRQHandler     ; 52:	MPT1 compare match0/overflow,IGBT cycle interrupt
                DCD     INTMTPTB11_IRQHandler     ; 53:	MPT1 compare match1/overflow,IGBT cycle interrupt
                DCD     INTMTCAP10_IRQHandler     ; 54:	MPT1 input capture0 interrupt
                DCD     INTMTCAP11_IRQHandler     ; 55:	MPT1 input capture1 interrupt
                DCD     INTTB0_IRQHandler         ; 56:	TMRB0 compare match detection interrupt
                DCD     INTTB1_IRQHandler         ; 57:	TMRB1 compare match detection interrupt
                DCD     INTTB2_IRQHandler         ; 58:	TMRB2 compare match detection interrupt
                DCD     INTTB3_IRQHandler         ; 59:	TMRB3 compare match detection interrupt
                DCD     INTTB4_IRQHandler         ; 60:	TMRB4 compare match detection interrupt
                DCD     INTTB5_IRQHandler         ; 61:	TMRB5 compare match detection interrupt
                DCD     INTTB6_IRQHandler         ; 62:	TMRB6 compare match detection interrupt
                DCD     INTTB7_IRQHandler         ; 63:	TMRB7 compare match detection interrupt
                DCD     INTTB8_IRQHandler         ; 64:	TMRB8 compare match detection interrupt
                DCD     INTTB9_IRQHandler         ; 65:	TMRB9 compare match detection interrupt
                DCD     INTTBA_IRQHandler         ; 66:	TMRBA compare match detection interrupt
                DCD     INTTBB_IRQHandler         ; 67:	TMRBB compare match detection interrupt
                DCD     INTTBC_IRQHandler         ; 68:	TMRBC compare match detection interrupt
                DCD     INTTBD_IRQHandler         ; 69:	TMRBD compare match detection interrupt
                DCD     INTTBE_IRQHandler         ; 70:	TMRBE compare match detection interrupt
                DCD     INTTBF_IRQHandler         ; 71:	TMRBF compare match detection interrupt
                DCD     INTCAP00_IRQHandler       ; 72:	TMRB0 input capture 0 interrupt
                DCD     INTCAP01_IRQHandler       ; 73:	TMRB0 input capture 1 interrupt
                DCD     INTCAP10_IRQHandler       ; 74:	TMRB1 input capture 0 interrupt
                DCD     INTCAP11_IRQHandler       ; 75:	TMRB1 input capture 1 interrupt
                DCD     INTCAP20_IRQHandler       ; 76:	TMRB2 input capture 0 interrupt
                DCD     INTCAP21_IRQHandler       ; 77:	TMRB2 input capture 1 interrupt
                DCD     INTCAP30_IRQHandler       ; 78:	TMRB3 input capture 0 interrupt
                DCD     INTCAP31_IRQHandler       ; 79:	TMRB3 input capture 1 interrupt
                DCD     INTCAP40_IRQHandler       ; 80:	TMRB4 input capture 0 interrupt
                DCD     INTCAP41_IRQHandler       ; 81:	TMRB4 input capture 1 interrupt
                DCD     INTCAP50_IRQHandler       ; 82:	TMRB5 input capture 0 interrupt
                DCD     INTCAP51_IRQHandler       ; 83:	TMRB5 input capture 1 interrupt
                DCD     INTCAP60_IRQHandler       ; 84:	TMRB6 input capture 0 interrupt
                DCD     INTCAP61_IRQHandler       ; 85:	TMRB6 input capture 1 interrupt
                DCD     INTCAP70_IRQHandler       ; 86:	TMRB7 input capture 0 interrupt
                DCD     INTCAP71_IRQHandler       ; 87:	TMRB7 input capture 1 interrupt
                DCD     INTCAP80_IRQHandler       ; 88:	TMRB8 input capture 0 interrupt
                DCD     INTCAP81_IRQHandler       ; 89:	TMRB8 input capture 1 interrupt
                DCD     INTCAP90_IRQHandler       ; 90:	TMRB9 input capture 0 interrupt
                DCD     INTCAP91_IRQHandler       ; 91:	TMRB9 input capture 1 interrupt
                DCD     INTCAPA0_IRQHandler       ; 92:	TMRBA input capture 0 interrupt
                DCD     INTCAPA1_IRQHandler       ; 93:	TMRBA input capture 1 interrupt
                DCD     INTCAPB0_IRQHandler       ; 94:	TMRBB input capture 0 interrupt
                DCD     INTCAPB1_IRQHandler       ; 95:	TMRBB input capture 1 interrupt
                DCD     INTCAPC0_IRQHandler       ; 96:	TMRBC input capture 0 interrupt
                DCD     INTCAPC1_IRQHandler       ; 97:	TMRBC input capture 1 interrupt
                DCD     INTCAPD0_IRQHandler       ; 98:	TMRBD input capture 0 interrupt
                DCD     INTCAPD1_IRQHandler       ; 99:	TMRBD input capture 1 interrupt
                DCD     INTCAPE0_IRQHandler       ; 100:	TMRBE input capture 0 interrupt
                DCD     INTCAPE1_IRQHandler       ; 101:	TMRBE input capture 1 interrupt
                DCD     INTCAPF0_IRQHandler       ; 102:	TMRBF input capture 0 interrupt
                DCD     INTCAPF1_IRQHandler       ; 103:	TMRBF input capture 1 interrupt
                DCD     INTDMAA_IRQHandler        ; 104:	DMAC transmission completion interrupt(unitA)
                DCD     INTDMAB_IRQHandler        ; 105:	DMAC transmission completion interrupt(unitB)
                DCD     INTDMAC_IRQHandler        ; 106:	DMAC transmission completion interrupt(unitC)
                DCD     INTDMAAERR_IRQHandler     ; 107:	DMAC transmission error interrupt(unitA)
                DCD     INTDMABERR_IRQHandler     ; 108:	DMAC transmission error interrupt(unitB)
                DCD     INTDMACERR_IRQHandler     ; 109:	DMAC transmission error interrupt(unitC)
                DCD     INTFLRDY_IRQHandler       ; 110:	Flash Ready interrupt
                DCD     INTRX6_IRQHandler         ; 111:	Serial6 reception interrupt
                DCD     INTTX6_IRQHandler         ; 112:	Serial6 transmission interrupt
                DCD     INTRX7_IRQHandler         ; 113:	Serial7 reception interrupt
                DCD     INTTX7_IRQHandler         ; 114:	Serial7 transmission interrupt
                DCD     INTRX8_IRQHandler         ; 115:	Serial8 reception interrupt
                DCD     INTTX8_IRQHandler         ; 116:	Serial8 transmission interrupt
                DCD     INTRX9_IRQHandler         ; 117:	Serial9 reception interrupt
                DCD     INTTX9_IRQHandler         ; 118:	Serial9 transmission interrupt
                DCD     INTRMCRX1_IRQHandler      ; 119:	Remote control rececptio 1 interrupt



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INT0_IRQHandler           [WEAK]
                EXPORT  INT1_IRQHandler           [WEAK]
                EXPORT  INT2_IRQHandler           [WEAK]
                EXPORT  INT3_IRQHandler           [WEAK]
                EXPORT  INT4_IRQHandler           [WEAK]
                EXPORT  INT5_IRQHandler           [WEAK]
                EXPORT  INT6_IRQHandler           [WEAK]
                EXPORT  INT7_IRQHandler           [WEAK]
                EXPORT  INT8_IRQHandler           [WEAK]
                EXPORT  INT9_IRQHandler           [WEAK]
                EXPORT  INTA_IRQHandler           [WEAK]
                EXPORT  INTB_IRQHandler           [WEAK]
                EXPORT  INTC_IRQHandler           [WEAK]
                EXPORT  INTD_IRQHandler           [WEAK]
                EXPORT  INTE_IRQHandler           [WEAK]
                EXPORT  INTF_IRQHandler           [WEAK]
                EXPORT  INTRX0_IRQHandler         [WEAK]
                EXPORT  INTTX0_IRQHandler         [WEAK]
                EXPORT  INTRX1_IRQHandler         [WEAK]
                EXPORT  INTTX1_IRQHandler         [WEAK]
                EXPORT  INTRX2_IRQHandler         [WEAK]
                EXPORT  INTTX2_IRQHandler         [WEAK]
                EXPORT  INTRX3_IRQHandler         [WEAK]
                EXPORT  INTTX3_IRQHandler         [WEAK]
                EXPORT  INTRX4_IRQHandler         [WEAK]
                EXPORT  INTTX4_IRQHandler         [WEAK]
                EXPORT  INTRX5_IRQHandler         [WEAK]
                EXPORT  INTTX5_IRQHandler         [WEAK]
                EXPORT  INTUART0_IRQHandler       [WEAK]
                EXPORT  INTUART1_IRQHandler       [WEAK]
                EXPORT  INTI2C0_IRQHandler        [WEAK]
                EXPORT  INTI2C1_IRQHandler        [WEAK]
                EXPORT  INTI2C2_IRQHandler        [WEAK]
                EXPORT  INTI2C3_IRQHandler        [WEAK]
                EXPORT  INTI2C4_IRQHandler        [WEAK]
                EXPORT  INTSSP0_IRQHandler        [WEAK]
                EXPORT  INTSSP1_IRQHandler        [WEAK]
                EXPORT  INTSSP2_IRQHandler        [WEAK]
                EXPORT  INTCECRX_IRQHandler       [WEAK]
                EXPORT  INTCECTX_IRQHandler       [WEAK]
                EXPORT  INTRMCRX0_IRQHandler      [WEAK]
                EXPORT  INTADHP_IRQHandler        [WEAK]
                EXPORT  INTADM0_IRQHandler        [WEAK]
                EXPORT  INTADM1_IRQHandler        [WEAK]
                EXPORT  INTAD_IRQHandler          [WEAK]
                EXPORT  INTRTC_IRQHandler         [WEAK]
                EXPORT  INTMTEMG0_IRQHandler      [WEAK]
                EXPORT  INTMTPTB00_IRQHandler     [WEAK]
                EXPORT  INTMTPTB01_IRQHandler     [WEAK]
                EXPORT  INTMTCAP00_IRQHandler     [WEAK]
                EXPORT  INTMTCAP01_IRQHandler     [WEAK]
                EXPORT  INTMTEMG1_IRQHandler      [WEAK]
                EXPORT  INTMTPTB10_IRQHandler     [WEAK]
                EXPORT  INTMTPTB11_IRQHandler     [WEAK]
                EXPORT  INTMTCAP10_IRQHandler     [WEAK]
                EXPORT  INTMTCAP11_IRQHandler     [WEAK]
                EXPORT  INTTB0_IRQHandler         [WEAK]
                EXPORT  INTTB1_IRQHandler         [WEAK]
                EXPORT  INTTB2_IRQHandler         [WEAK]
                EXPORT  INTTB3_IRQHandler         [WEAK]
                EXPORT  INTTB4_IRQHandler         [WEAK]
                EXPORT  INTTB5_IRQHandler         [WEAK]
                EXPORT  INTTB6_IRQHandler         [WEAK]
                EXPORT  INTTB7_IRQHandler         [WEAK]
                EXPORT  INTTB8_IRQHandler         [WEAK]
                EXPORT  INTTB9_IRQHandler         [WEAK]
                EXPORT  INTTBA_IRQHandler         [WEAK]
                EXPORT  INTTBB_IRQHandler         [WEAK]
                EXPORT  INTTBC_IRQHandler         [WEAK]
                EXPORT  INTTBD_IRQHandler         [WEAK]
                EXPORT  INTTBE_IRQHandler         [WEAK]
                EXPORT  INTTBF_IRQHandler         [WEAK]
                EXPORT  INTCAP00_IRQHandler       [WEAK]
                EXPORT  INTCAP01_IRQHandler       [WEAK]
                EXPORT  INTCAP10_IRQHandler       [WEAK]
                EXPORT  INTCAP11_IRQHandler       [WEAK]
                EXPORT  INTCAP20_IRQHandler       [WEAK]
                EXPORT  INTCAP21_IRQHandler       [WEAK]
                EXPORT  INTCAP30_IRQHandler       [WEAK]
                EXPORT  INTCAP31_IRQHandler       [WEAK]
                EXPORT  INTCAP40_IRQHandler       [WEAK]
                EXPORT  INTCAP41_IRQHandler       [WEAK]
                EXPORT  INTCAP50_IRQHandler       [WEAK]
                EXPORT  INTCAP51_IRQHandler       [WEAK]
                EXPORT  INTCAP60_IRQHandler       [WEAK]
                EXPORT  INTCAP61_IRQHandler       [WEAK]
                EXPORT  INTCAP70_IRQHandler       [WEAK]
                EXPORT  INTCAP71_IRQHandler       [WEAK]
                EXPORT  INTCAP80_IRQHandler       [WEAK]
                EXPORT  INTCAP81_IRQHandler       [WEAK]
                EXPORT  INTCAP90_IRQHandler       [WEAK]
                EXPORT  INTCAP91_IRQHandler       [WEAK]
                EXPORT  INTCAPA0_IRQHandler       [WEAK]
                EXPORT  INTCAPA1_IRQHandler       [WEAK]
                EXPORT  INTCAPB0_IRQHandler       [WEAK]
                EXPORT  INTCAPB1_IRQHandler       [WEAK]
                EXPORT  INTCAPC0_IRQHandler       [WEAK]
                EXPORT  INTCAPC1_IRQHandler       [WEAK]
                EXPORT  INTCAPD0_IRQHandler       [WEAK]
                EXPORT  INTCAPD1_IRQHandler       [WEAK]
                EXPORT  INTCAPE0_IRQHandler       [WEAK]
                EXPORT  INTCAPE1_IRQHandler       [WEAK]
                EXPORT  INTCAPF0_IRQHandler       [WEAK]
                EXPORT  INTCAPF1_IRQHandler       [WEAK]
                EXPORT  INTDMAA_IRQHandler        [WEAK]
                EXPORT  INTDMAB_IRQHandler        [WEAK]
                EXPORT  INTDMAC_IRQHandler        [WEAK]
                EXPORT  INTDMAAERR_IRQHandler     [WEAK]
                EXPORT  INTDMABERR_IRQHandler     [WEAK]
                EXPORT  INTDMACERR_IRQHandler     [WEAK]
                EXPORT  INTFLRDY_IRQHandler       [WEAK]
                EXPORT  INTRX6_IRQHandler         [WEAK]
                EXPORT  INTTX6_IRQHandler         [WEAK]
                EXPORT  INTRX7_IRQHandler         [WEAK]
                EXPORT  INTTX7_IRQHandler         [WEAK]
                EXPORT  INTRX8_IRQHandler         [WEAK]
                EXPORT  INTTX8_IRQHandler         [WEAK]
                EXPORT  INTRX9_IRQHandler         [WEAK]
                EXPORT  INTTX9_IRQHandler         [WEAK]
                EXPORT  INTRMCRX1_IRQHandler      [WEAK]

INT0_IRQHandler
INT1_IRQHandler
INT2_IRQHandler
INT3_IRQHandler
INT4_IRQHandler
INT5_IRQHandler
INT6_IRQHandler
INT7_IRQHandler
INT8_IRQHandler
INT9_IRQHandler
INTA_IRQHandler
INTB_IRQHandler
INTC_IRQHandler
INTD_IRQHandler
INTE_IRQHandler
INTF_IRQHandler
INTRX0_IRQHandler
INTTX0_IRQHandler
INTRX1_IRQHandler
INTTX1_IRQHandler
INTRX2_IRQHandler
INTTX2_IRQHandler
INTRX3_IRQHandler
INTTX3_IRQHandler
INTRX4_IRQHandler
INTTX4_IRQHandler
INTRX5_IRQHandler
INTTX5_IRQHandler
INTUART0_IRQHandler
INTUART1_IRQHandler
INTI2C0_IRQHandler
INTI2C1_IRQHandler
INTI2C2_IRQHandler
INTI2C3_IRQHandler
INTI2C4_IRQHandler
INTSSP0_IRQHandler
INTSSP1_IRQHandler
INTSSP2_IRQHandler
INTCECRX_IRQHandler
INTCECTX_IRQHandler
INTRMCRX0_IRQHandler
INTADHP_IRQHandler
INTADM0_IRQHandler
INTADM1_IRQHandler
INTAD_IRQHandler
INTRTC_IRQHandler
INTMTEMG0_IRQHandler
INTMTPTB00_IRQHandler
INTMTPTB01_IRQHandler
INTMTCAP00_IRQHandler
INTMTCAP01_IRQHandler
INTMTEMG1_IRQHandler
INTMTPTB10_IRQHandler
INTMTPTB11_IRQHandler
INTMTCAP10_IRQHandler
INTMTCAP11_IRQHandler
INTTB0_IRQHandler
INTTB1_IRQHandler
INTTB2_IRQHandler
INTTB3_IRQHandler
INTTB4_IRQHandler
INTTB5_IRQHandler
INTTB6_IRQHandler
INTTB7_IRQHandler
INTTB8_IRQHandler
INTTB9_IRQHandler
INTTBA_IRQHandler
INTTBB_IRQHandler
INTTBC_IRQHandler
INTTBD_IRQHandler
INTTBE_IRQHandler
INTTBF_IRQHandler
INTCAP00_IRQHandler
INTCAP01_IRQHandler
INTCAP10_IRQHandler
INTCAP11_IRQHandler
INTCAP20_IRQHandler
INTCAP21_IRQHandler
INTCAP30_IRQHandler
INTCAP31_IRQHandler
INTCAP40_IRQHandler
INTCAP41_IRQHandler
INTCAP50_IRQHandler
INTCAP51_IRQHandler
INTCAP60_IRQHandler
INTCAP61_IRQHandler
INTCAP70_IRQHandler
INTCAP71_IRQHandler
INTCAP80_IRQHandler
INTCAP81_IRQHandler
INTCAP90_IRQHandler
INTCAP91_IRQHandler
INTCAPA0_IRQHandler
INTCAPA1_IRQHandler
INTCAPB0_IRQHandler
INTCAPB1_IRQHandler
INTCAPC0_IRQHandler
INTCAPC1_IRQHandler
INTCAPD0_IRQHandler
INTCAPD1_IRQHandler
INTCAPE0_IRQHandler
INTCAPE1_IRQHandler
INTCAPF0_IRQHandler
INTCAPF1_IRQHandler
INTDMAA_IRQHandler
INTDMAB_IRQHandler
INTDMAC_IRQHandler
INTDMAAERR_IRQHandler
INTDMABERR_IRQHandler
INTDMACERR_IRQHandler
INTFLRDY_IRQHandler
INTRX6_IRQHandler
INTTX6_IRQHandler
INTRX7_IRQHandler
INTTX7_IRQHandler
INTRX8_IRQHandler
INTTX8_IRQHandler
INTRX9_IRQHandler
INTTX9_IRQHandler
INTRMCRX1_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

